@@ -638,12 +638,10 @@ ephy_embed_shell_get_global_gsb_service (EphyEmbedShell *shell)
   g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (!priv->global_gsb_service) {
-    g_autofree char *api_key = NULL;
     g_autofree char *db_path = NULL;
 
-    api_key = g_settings_get_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_GSB_API_KEY);
     db_path = g_build_filename (ephy_default_cache_dir (), EPHY_GSB_FILE, NULL);
-    priv->global_gsb_service = ephy_gsb_service_new (api_key, db_path);
+    priv->global_gsb_service = ephy_gsb_service_new (GSB_API_KEY, db_path);
   }
 
   return priv->global_gsb_service;
@@ -902,12 +900,6 @@ ephy_embed_shell_startup (GApplication *application)
     /* Favicon Database */
     favicon_db_path = g_build_filename (ephy_cache_dir (), "icondatabase", NULL);
     webkit_web_context_set_favicon_database_directory (priv->web_context, favicon_db_path);
-
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-    /* Do not ignore TLS errors. */
-    webkit_web_context_set_tls_errors_policy (priv->web_context, WEBKIT_TLS_ERRORS_POLICY_FAIL);
-#pragma GCC diagnostic pop
   }
 
   /* about: URIs handler */
